<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>DialogSettings</name>
    <message>
        <location filename="../ui/dialogsettings.ui" line="14"/>
        <source>Dialog</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="250"/>
        <source>Internet updates</source>
        <translation>Mises à jour internet</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="259"/>
        <source>Update now</source>
        <translation>Mettre à jour maintenant</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="30"/>
        <source>Layout</source>
        <translation>Disposition</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="24"/>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="64"/>
        <source>Preview on the &amp;left</source>
        <translation>Prévisualisation à &amp;gauche</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="94"/>
        <source>Pre&amp;view on right side</source>
        <translation>Prévisualisation à &amp;droite</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="113"/>
        <source>Theme</source>
        <translation>Thème</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="119"/>
        <source>&amp;Default</source>
        <translation>&amp;Défaut</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="126"/>
        <source>Dar&amp;k</source>
        <translation>&amp;Sombre</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="139"/>
        <source>&lt;i&gt;(Restart needed)&lt;/I&gt;</source>
        <translation>&lt;i&gt;(Changements effectifs&lt;br/&gt;au prochain lancement.)&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="149"/>
        <source>Language</source>
        <translation>Langue</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="179"/>
        <source>Always enable preview zooming</source>
        <translation>Toujours activer le zoom</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="186"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-style:italic;&quot;&gt;(Warning: preview may be inaccurate&lt;br/&gt;if checked.)&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-style:italic;&quot;&gt;(Attention : l&apos;aperçu peut être faussé si ce choix est activé.)&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="196"/>
        <source>Misc</source>
        <translation>Divers</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="209"/>
        <source>Use native file dialog</source>
        <translation>Dialogues de choix de fichier natifs</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="216"/>
        <source>&amp;Enable High-DPI support</source>
        <translation>&amp;Activer le High DPI</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="223"/>
        <source>&lt;i&gt;(Restart needed)&lt;/i&gt;</source>
        <translation>&lt;i&gt;(Changement effectif&lt;br/&gt;au prochain lancement.)&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="239"/>
        <source>Filter sources</source>
        <translation>Sources de filtres</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="244"/>
        <source>Other</source>
        <translation>Autre</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="282"/>
        <source>Output messages</source>
        <translation>Messages de sortie</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="202"/>
        <source>&amp;Use native color dialog</source>
        <translation>&amp;Dialogues de choix de couleur natifs</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="163"/>
        <source>Preview</source>
        <translation>Aperçu</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="169"/>
        <source>Timeout (seconds)</source>
        <translation>Délai max. (secondes)</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="36"/>
        <source>Show institution logos</source>
        <translation>Afficher les logos institutionnels</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="291"/>
        <source>Notify when scheduled update fails</source>
        <translation>Signaler quand une mise à jour automatique échoue</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="333"/>
        <source>&amp;Ok</source>
        <translation>&amp;Ok</translation>
    </message>
</context>
<context>
    <name>FiltersView</name>
    <message>
        <location filename="../ui/filtersview.ui" line="14"/>
        <source>Form</source>
        <translation>GMIC</translation>
    </message>
</context>
<context>
    <name>GmicQt::ColorParameter</name>
    <message>
        <location filename="../src/FilterParameters/ColorParameter.cpp" line="213"/>
        <source>Select color</source>
        <translation>Sélectionnez une couleur</translation>
    </message>
</context>
<context>
    <name>GmicQt::DialogSettings</name>
    <message>
        <location filename="../src/DialogSettings.cpp" line="45"/>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="51"/>
        <source>Never</source>
        <translation>Jamais</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="52"/>
        <source>Daily</source>
        <translation>Journalière</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="53"/>
        <source>Weekly</source>
        <translation>Hebdomadaire</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="54"/>
        <source>Every 2 weeks</source>
        <translation>Toutes les deux semaines</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="55"/>
        <source>Monthly</source>
        <translation>Mensuelle</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="57"/>
        <source>At launch (debug)</source>
        <translation>À chaque lancement (débugage)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="65"/>
        <source>Output messages</source>
        <translation>Messages de sortie</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="66"/>
        <source>Quiet (default)</source>
        <translation>Aucun message (défaut)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="67"/>
        <source>Verbose (console)</source>
        <translation>Mode verbeux (console)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="68"/>
        <source>Verbose (log file)</source>
        <translation>Mode verbeux (fichier de log)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="69"/>
        <source>Very verbose (console)</source>
        <translation>Mode très verbeux (console)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="70"/>
        <source>Very verbose (log file)</source>
        <translation>Mode très verbeux (fichier de log)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="71"/>
        <source>Debug (console)</source>
        <translation>Mode débogage (console)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="72"/>
        <source>Debug (log file)</source>
        <translation>Mode débogage (fichier de log)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="88"/>
        <source>Check to use Native/OS color dialog, uncheck to use Qt&apos;s</source>
        <translation>Cocher pour utiliser les dialogues natifs, décocher pour utiliser les dialogues Qt</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="90"/>
        <source>Check to use Native/OS file dialog, uncheck to use Qt&apos;s</source>
        <translation>Cocher pour utiliser les dialogues de fichier natifs, décocher pour utiliser les dialogues Qt</translation>
    </message>
</context>
<context>
    <name>GmicQt::FileParameter</name>
    <message>
        <location filename="../src/FilterParameters/FileParameter.cpp" line="159"/>
        <location filename="../src/FilterParameters/FileParameter.cpp" line="162"/>
        <location filename="../src/FilterParameters/FileParameter.cpp" line="165"/>
        <source>Select a file</source>
        <translation>Sélectionnez un fichier</translation>
    </message>
</context>
<context>
    <name>GmicQt::FilterParametersWidget</name>
    <message>
        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="44"/>
        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="273"/>
        <source>&lt;i&gt;Select a filter&lt;/i&gt;</source>
        <translation>&lt;i&gt;Sélectionnez un filtre&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="240"/>
        <source>&lt;i&gt;No parameters&lt;/i&gt;</source>
        <translation>&lt;i&gt;Aucun paramètre&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="245"/>
        <source>Error parsing filter parameters

</source>
        <translation>Erreur d&apos;analyse des paramètres du filtre

</translation>
    </message>
</context>
<context>
    <name>GmicQt::FiltersPresenter</name>
    <message>
        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="513"/>
        <source>Unknown filter</source>
        <translation>Filtre inconnu</translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="623"/>
        <source>Cannot find this fave&apos;s original filter
</source>
        <translation>Filtre original introuvable pour ce favori
</translation>
    </message>
</context>
<context>
    <name>GmicQt::FiltersView</name>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="353"/>
        <source>Remove fave</source>
        <translation>Supprimer le favori</translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="680"/>
        <source>Rename Fave</source>
        <translation>Renommer le favori</translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="682"/>
        <source>Remove Fave</source>
        <translation>Supprimer le favori</translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="684"/>
        <source>Clone Fave</source>
        <translation>Dupliquer le favori</translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="688"/>
        <source>Add Fave</source>
        <translation>Ajouter comme favori</translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="707"/>
        <source>Remove All</source>
        <translation>Supprimer tous les marqueurs</translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="714"/>
        <source>%1 (%2 %3)</source>
        <translation>%1 (%2 %3)</translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="714"/>
        <source>Filters</source>
        <translation>filtres</translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="714"/>
        <source>Filter</source>
        <translation>filtre</translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="354"/>
        <source>Do you really want to remove the following fave?

%1
</source>
        <translation>Êtes-vous certain de vouloir supprimer le favori ci-dessous ?

%1
</translation>
    </message>
</context>
<context>
    <name>GmicQt::FolderParameter</name>
    <message>
        <location filename="../src/FilterParameters/FolderParameter.cpp" line="138"/>
        <source>Select a folder</source>
        <translation>Sélectionnez un dossier</translation>
    </message>
</context>
<context>
    <name>GmicQt::GmicProcessor</name>
    <message>
        <location filename="../src/GmicProcessor.cpp" line="416"/>
        <source>Image #%1 returned by filter has %2 channels (should be at most 4)</source>
        <translation>L&apos;image No%1 retournée par le filtre possède %2 canaux (4 est la limite)</translation>
    </message>
    <message>
        <location filename="../src/GmicProcessor.cpp" line="452"/>
        <source>Image #%1 returned by filter has %2 channels
(should be at most 4)</source>
        <translation>L&apos;image No%1 retournée par le filtre possède %2 canaux
(4 est la limite)</translation>
    </message>
</context>
<context>
    <name>GmicQt::HeadlessProcessor</name>
    <message>
        <location filename="../src/HeadlessProcessor.cpp" line="79"/>
        <source>At least a filter path or a filter command must be provided.</source>
        <translation>Au moins un chemin de filtre ou une commande doivent être founis.</translation>
    </message>
    <message>
        <location filename="../src/HeadlessProcessor.cpp" line="81"/>
        <source>Custom command (%1)</source>
        <translation>Commande personnalisée (%1)</translation>
    </message>
    <message>
        <location filename="../src/HeadlessProcessor.cpp" line="89"/>
        <source>Cannot find filter matching path %1</source>
        <translation>Impossible de trouver un filtre correspondant au chemin %1</translation>
    </message>
    <message>
        <location filename="../src/HeadlessProcessor.cpp" line="96"/>
        <source>Error parsing filter parameters definition for filter:

%1

Cannot retrieve default parameters.

%2</source>
        <translation>Erreur de lecture de la définition des paramètres pour le filtre :

%1

Impossible de déterminer les paramètres par défaut.

%2</translation>
    </message>
    <message>
        <location filename="../src/HeadlessProcessor.cpp" line="114"/>
        <source>Error parsing supplied command: %1</source>
        <translation>Erreur d&apos;analyse de la commande fournie: %1</translation>
    </message>
    <message>
        <location filename="../src/HeadlessProcessor.cpp" line="117"/>
        <source>Supplied command (%1) does not match path (%2), (should be %3).</source>
        <translation>La commande fournie (%1) ne correspond pas au chemin (%2), (ce devrait être %3).</translation>
    </message>
    <message>
        <location filename="../src/HeadlessProcessor.cpp" line="229"/>
        <source>Filter execution failed, but with no error message.</source>
        <translation>L&apos;exécution du filtre a échoué, mais sans message d&apos;erreur.</translation>
    </message>
</context>
<context>
    <name>GmicQt::InOutPanel</name>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="62"/>
        <source>Input layers</source>
        <translation>Calques en entrée</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="68"/>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="69"/>
        <source>Active (default)</source>
        <translation>Actif (défaut)</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="70"/>
        <source>All</source>
        <translation>Tous</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="71"/>
        <source>Active and below</source>
        <translation>Actif et en dessous</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="72"/>
        <source>Active and above</source>
        <translation>Actif et au dessus</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="73"/>
        <source>All visible</source>
        <translation>Tous les calques visibles</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="74"/>
        <source>All invisible</source>
        <translation>Tous les calques invisibles</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="85"/>
        <source>Output mode</source>
        <translation>Mode de sortie</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="91"/>
        <source>In place (default)</source>
        <translation>Sur place (défaut)</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="92"/>
        <source>New layer(s)</source>
        <translation>Nouveau(x) calque(s)</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="93"/>
        <source>New active layer(s)</source>
        <translation>Nouveau(x) calque(s) actif(s)</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="94"/>
        <source>New image</source>
        <translation>Nouvelle image</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="205"/>
        <source>Input / Output</source>
        <translation>Entrée / Sortie</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="207"/>
        <source>Input</source>
        <translation>Entrée</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="209"/>
        <source>Output</source>
        <translation>Sortie</translation>
    </message>
</context>
<context>
    <name>GmicQt::LanguageSelectionWidget</name>
    <message>
        <location filename="../src/Widgets/LanguageSelectionWidget.cpp" line="53"/>
        <source>System default (%1)</source>
        <translation>Langue du système (%1)</translation>
    </message>
    <message>
        <location filename="../src/Widgets/LanguageSelectionWidget.cpp" line="62"/>
        <source>Translations are very likely to be incomplete.</source>
        <translation>La traduction est certainement très incomplète.</translation>
    </message>
</context>
<context>
    <name>GmicQt::MainWindow</name>
    <message>
        <location filename="../src/MainWindow.cpp" line="108"/>
        <source>Add fave</source>
        <translation>Ajouter un favori</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="110"/>
        <source>Reset parameters to default values</source>
        <translation>Réinitialiser les paramètres du filtre</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="113"/>
        <source>Randomize parameters</source>
        <translation>Paramètres aléatoires</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="119"/>
        <source>Copy G&apos;MIC command to clipboard</source>
        <translation>Copier la commande G&apos;MIC dans le presse-papier</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="126"/>
        <source>Rename fave</source>
        <translation>Renommer un favori</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="128"/>
        <source>Remove fave</source>
        <translation>Supprimer un favori</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="132"/>
        <source>Expand/Collapse all</source>
        <translation>Déplier/Réduire tout</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="134"/>
        <source>G&apos;MIC (https://gmic.eu)&lt;br/&gt;GREYC (https://www.greyc.fr)&lt;br/&gt;CNRS (https://www.cnrs.fr)&lt;br/&gt;Normandy University (https://www.unicaen.fr)&lt;br/&gt;Ensicaen (https://www.ensicaen.fr)</source>
        <translation>G&apos;MIC (https://gmic.eu)&lt;br/&gt;GREYC (https://www.greyc.fr)&lt;br/&gt;CNRS (https://www.cnrs.fr)&lt;br/&gt;Normandie Université (https://www.unicaen.fr)&lt;br/&gt;Ensicaen (https://www.ensicaen.fr)</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="141"/>
        <source>Selection mode</source>
        <translation>Mode sélection</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="180"/>
        <source>Update filters</source>
        <translation>Mettre à jour les filtres (Ctrl+R / F5)</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="232"/>
        <source>Manage visible tags
(Right-click on a fave or a filter to set/remove tags)</source>
        <translation>Gérer les tags visibles
(Ajouter/supprimer des tags par clic droit sur un favori ou sur un filtre)</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="238"/>
        <source>Force &amp;quit</source>
        <translation>Forcer la &amp;terminaison</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="242"/>
        <source>Full</source>
        <translation>Entier</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="243"/>
        <source>Forward Horizontal</source>
        <translation>Séparation horizontale avant</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="244"/>
        <source>Forward Vertical</source>
        <translation>Séparation verticale avant</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="245"/>
        <source>Backward Horizontal</source>
        <translation>Séparation horizontale arrière</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="246"/>
        <source>Backward Vertical</source>
        <translation>Séparation verticale arrière</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="247"/>
        <source>Duplicate Top</source>
        <translation>Copie en haut</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="248"/>
        <source>Duplicate Left</source>
        <translation>Copie à gauche</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="249"/>
        <source>Duplicate Bottom</source>
        <translation>Copie en bas</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="250"/>
        <source>Duplicate Right</source>
        <translation>Copie à droite</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="251"/>
        <source>Duplicate Horizontal</source>
        <translation>Copie horizontale</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="252"/>
        <source>Duplicate Vertical</source>
        <translation>Copie verticale</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="253"/>
        <source>Checkered</source>
        <translation>En damier</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="254"/>
        <source>Checkered Inverse</source>
        <translation>En damier inversé</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="372"/>
        <source>Update completed</source>
        <translation>Mise à jour réussie</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="372"/>
        <location filename="../src/MainWindow.cpp" line="374"/>
        <location filename="../src/MainWindow.cpp" line="505"/>
        <source>Filter definitions have been updated.</source>
        <translation>Les définitions de filtres ont été mises à jour.</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="377"/>
        <source>No download was needed.</source>
        <translation>Aucun téléchargement n&apos;était requis.</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="423"/>
        <source>Plugin was called with a filter path with no matching filter:

Path: %1</source>
        <translation>Le plugin a été appelé avec un chemin qui ne correspond à aucun filtre :

Chemin: %1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="431"/>
        <location filename="../src/MainWindow.cpp" line="458"/>
        <source>Error parsing filter parameters definition for filter:

%1

Cannot retrieve default parameters.

%2</source>
        <translation>Erreur de lecture de la définition des paramètres pour le filtre :

%1

Impossible de déterminer les paramètres par défaut.

%2</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="444"/>
        <source>Plugin was called with a command that cannot be recognized as a filter:

Command: %1</source>
        <translation>Le plugin a été appelé avec une commande qui ne correspond à aucun filtre :

Commande: %1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="923"/>
        <source>[Elapsed time: %1]</source>
        <translation>[Temps écoulé : %1]</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="439"/>
        <source>Plugin was called with a command that cannot be parsed:

%1</source>
        <translation>Le plugin a été appelé avec une commande invalide :

%1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="448"/>
        <source>Plugin was called with a command that does not match the provided path:

Path: %1
Command: %2
Command found for this path : %3</source>
        <translation>Le plugin a été appelé avec une commande qui ne correspond pas au chemin fourni :

Chemin : %1
Commande : %2
Commande trouvée pour le chemin : %3</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="501"/>
        <source>Filters update could not be achieved</source>
        <translation>La mise à jour des filtres n&apos;a pas réussi</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="642"/>
        <source>The update could not be achieved&lt;br&gt;because of the following errors:&lt;br&gt;</source>
        <translation>La mise à jour n&apos;a pas réussi en raison&lt;br/&gt;des erreurs suivantes :&lt;br/&gt;</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="648"/>
        <source>Update error</source>
        <translation>Erreurs lors de la mise à jour</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="855"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="1474"/>
        <source>Waiting for cancelled jobs...</source>
        <translation>En attente des traitements annulés...</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="1328"/>
        <source>Import faves</source>
        <translation>Importer les favoris</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="1328"/>
        <source>Do you want to import faves from file below?&lt;br/&gt;%1</source>
        <translation>Voulez-vous importer les favoris du fichier ci-dessous ?&lt;br/&gt;%1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="1331"/>
        <source>Don&apos;t ask again</source>
        <translation>Ne plus me demander</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="1450"/>
        <source>Confirmation</source>
        <translation>Confirmation</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="1450"/>
        <source>A gmic command is running.&lt;br&gt;Do you really want to close the plugin?</source>
        <translation>Une commande gmic est en cours d&apos;exécution.&lt;br&gt;Voulez-vous vraiment fermer le plugin ?</translation>
    </message>
</context>
<context>
    <name>GmicQt::MultilineTextParameterWidget</name>
    <message>
        <location filename="../src/FilterParameters/MultilineTextParameterWidget.cpp" line="41"/>
        <source>Ctrl+Return</source>
        <translation>Ctrl+Entrée</translation>
    </message>
</context>
<context>
    <name>GmicQt::ProgressInfoWidget</name>
    <message>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="50"/>
        <source>G&apos;MIC-Qt Plug-in progression</source>
        <translation>Progression du greffon G&apos;MIC-Qt</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="53"/>
        <source>Abort</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="126"/>
        <source>[Processing 88:00:00.888 | 888.9 GiB]</source>
        <translation>[Traitement en cours 88:00:00.888 | 888.9 Gio]</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="128"/>
        <source>[Processing 88:00:00.888]</source>
        <translation>[Traitement en cours 88:00:00.888]</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="160"/>
        <source>Updating filters...</source>
        <translation>Mise à jour des filtres...</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="213"/>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="221"/>
        <source>[Processing %1 | %2]</source>
        <translation>[Traitement en cours %1 | %2]</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="223"/>
        <source>[Processing %1]</source>
        <translation>[Traitement en cours %1]</translation>
    </message>
</context>
<context>
    <name>GmicQt::ProgressInfoWindow</name>
    <message>
        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="49"/>
        <source>G&apos;MIC-Qt Plug-in progression</source>
        <translation>Progression du greffon G&apos;MIC-Qt</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="141"/>
        <source>%1 seconds</source>
        <translation>%1 secondes</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="151"/>
        <source>[Processing %1 | %2]</source>
        <translation>[Traitement en cours %1 | %2]</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="153"/>
        <source>[Processing %1]</source>
        <translation>[Traitement en cours %1]</translation>
    </message>
</context>
<context>
    <name>GmicQt::SearchFieldWidget</name>
    <message>
        <location filename="../src/Widgets/SearchFieldWidget.cpp" line="80"/>
        <source>Search</source>
        <translation>Rechercher</translation>
    </message>
    <message>
        <location filename="../src/Widgets/SearchFieldWidget.cpp" line="81"/>
        <source>Search in filters list (%1)</source>
        <translation>Rechercher dans la liste des filtres (%1)</translation>
    </message>
</context>
<context>
    <name>GmicQt::SourcesWidget</name>
    <message>
        <location filename="../src/SourcesWidget.cpp" line="58"/>
        <source>Move source up</source>
        <translation>Déplacer la source vers le haut</translation>
    </message>
    <message>
        <location filename="../src/SourcesWidget.cpp" line="60"/>
        <source>Move source down</source>
        <translation>Déplacer la source vers le bas</translation>
    </message>
    <message>
        <location filename="../src/SourcesWidget.cpp" line="62"/>
        <source>Add local file (dialog)</source>
        <translation>Ajouter un fichier local (dialogue)</translation>
    </message>
    <message>
        <location filename="../src/SourcesWidget.cpp" line="64"/>
        <source>Reset filter sources</source>
        <translation>Réinitialiser les sources de filtres</translation>
    </message>
    <message>
        <location filename="../src/SourcesWidget.cpp" line="80"/>
        <source>Macros: $HOME %USERPROFILE% $VERSION</source>
        <translation>Macros: $HOME %USERPROFILE% $VERSION</translation>
    </message>
    <message>
        <location filename="../src/SourcesWidget.cpp" line="102"/>
        <source>Environment variables (e.g. %USERPROFILE% or %HOMEDIR%) are substituted in sources.
VERSION is also a predefined variable that stands for the G&apos;MIC version number (currently %1).</source>
        <translation>Les variables d&apos;environement (e.g. %USERPROFILE% ou %HOMEDIR%) sont substituées dans les sources.
VERSION est aussi une variable définie comme le numéro de version courante de G&apos;MIC (actuellement %1).</translation>
    </message>
    <message>
        <location filename="../src/SourcesWidget.cpp" line="82"/>
        <source>Macros: $HOME $VERSION</source>
        <translation>Macros : $HOME $VERSION</translation>
    </message>
    <message>
        <location filename="../src/SourcesWidget.cpp" line="53"/>
        <source>Remove source (Delete)</source>
        <translation>Supprimer une source (Suppr)</translation>
    </message>
    <message>
        <location filename="../src/SourcesWidget.cpp" line="85"/>
        <source>Disable</source>
        <translation>Désactiver</translation>
    </message>
    <message>
        <location filename="../src/SourcesWidget.cpp" line="86"/>
        <source>Enable without updates</source>
        <translation>Activer sans les mises à jour</translation>
    </message>
    <message>
        <location filename="../src/SourcesWidget.cpp" line="87"/>
        <source>Enable with updates (recommended)</source>
        <translation>Activer avec les mises à jour (recommandé)</translation>
    </message>
    <message>
        <location filename="../src/SourcesWidget.cpp" line="106"/>
        <source>Environment variables (e.g. $HOME or ${HOME} for your home directory) are substituted in sources.
VERSION is also a predefined variable that stands for the G&apos;MIC version number (currently %1).</source>
        <translation>Les variables d&apos;environnement (e.g. $HOME ou ${HOME}) sont substituées dans les sources.
VERSION est aussi une variable prédéfinie à la valeur de la version de G&apos;MIC (actuellement %1).</translation>
    </message>
    <message>
        <location filename="../src/SourcesWidget.cpp" line="111"/>
        <source>New source</source>
        <translation>Nouvelle source</translation>
    </message>
    <message>
        <location filename="../src/SourcesWidget.cpp" line="192"/>
        <source>Select a file</source>
        <translation>Sélectionnez un fichier</translation>
    </message>
</context>
<context>
    <name>GmicQt::Updater</name>
    <message>
        <location filename="../src/Updater.cpp" line="137"/>
        <source>Error downloading %1 (empty file?)</source>
        <translation>Erreur de téléchargement de %1 (fichier vide ?)</translation>
    </message>
    <message>
        <location filename="../src/Updater.cpp" line="146"/>
        <source>Could not read/decompress %1</source>
        <translation>Impossible de lire/décompresser %1</translation>
    </message>
    <message>
        <location filename="../src/Updater.cpp" line="151"/>
        <source>Error writing file %1</source>
        <translation>Erreur d&apos;écriture du fichier %1</translation>
    </message>
    <message>
        <location filename="../src/Updater.cpp" line="168"/>
        <source>Error downloading %1&lt;br/&gt;Error %2: %3</source>
        <translation>Erreur lors du téléchargement de %1&lt;br/&gt; Erreur %2 : %3</translation>
    </message>
    <message>
        <location filename="../src/Updater.cpp" line="204"/>
        <source>Download timeout: %1</source>
        <translation>Téléchargement annulé (hors délai) : %1</translation>
    </message>
</context>
<context>
    <name>GmicQt::VisibleTagSelector</name>
    <message>
        <location filename="../src/Widgets/VisibleTagSelector.cpp" line="55"/>
        <source>Show All Filters</source>
        <translation>Montrer tous les filtres</translation>
    </message>
    <message>
        <location filename="../src/Widgets/VisibleTagSelector.cpp" line="59"/>
        <source>Show %1 Tags</source>
        <translation>Montrer les marqueurs %1s</translation>
    </message>
</context>
<context>
    <name>GmicQt::ZoomLevelSelector</name>
    <message>
        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="54"/>
        <source>Zoom in</source>
        <translation>Zoom avant</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="55"/>
        <source>Zoom out</source>
        <translation>Zoom arrière</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="56"/>
        <source>Reset zoom</source>
        <translation>Zoom par défaut</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="155"/>
        <source>Warning: Preview may be inaccurate (zoom factor has been modified)</source>
        <translation>Attention : l&apos;aperçu peut être erroné (le facteur de zoom a été modifié)</translation>
    </message>
</context>
<context>
    <name>HeadlessProgressDialog</name>
    <message>
        <location filename="../ui/headlessprogressdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Progression</translation>
    </message>
    <message>
        <location filename="../ui/headlessprogressdialog.ui" line="68"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>InOutPanel</name>
    <message>
        <location filename="../ui/inoutpanel.ui" line="40"/>
        <source>Input / Output</source>
        <translation>Entrée / Sortie</translation>
    </message>
    <message>
        <location filename="../ui/inoutpanel.ui" line="47"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../ui/inoutpanel.ui" line="92"/>
        <source>Input layers</source>
        <translation>Calques en entrée</translation>
    </message>
    <message>
        <location filename="../ui/inoutpanel.ui" line="115"/>
        <source>Output mode</source>
        <translation>Mode de sortie</translation>
    </message>
</context>
<context>
    <name>JpegQualityDialog</name>
    <message>
        <location filename="../src/Host/None/jpegqualitydialog.ui" line="14"/>
        <source>Dialog</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/Host/None/jpegqualitydialog.ui" line="20"/>
        <location filename="../src/Host/None/JpegQualityDialog.cpp" line="13"/>
        <source>JPEG Quality</source>
        <translation>Facteur de qualité JPEG</translation>
    </message>
    <message>
        <location filename="../src/Host/None/jpegqualitydialog.ui" line="28"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../src/Host/None/jpegqualitydialog.ui" line="42"/>
        <source>100</source>
        <translation>100</translation>
    </message>
    <message>
        <location filename="../src/Host/None/jpegqualitydialog.ui" line="60"/>
        <source>Always use this quality for this execution of G&apos;MIC-Qt</source>
        <translation>Toujours cette qualité pour cette exécution de G&apos;MIC-Qt</translation>
    </message>
    <message>
        <location filename="../src/Host/None/jpegqualitydialog.ui" line="85"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <location filename="../src/Host/None/jpegqualitydialog.ui" line="92"/>
        <source>&amp;Ok</source>
        <translation>&amp;Ok</translation>
    </message>
</context>
<context>
    <name>LanguageSelectionWidget</name>
    <message>
        <location filename="../ui/languageselectionwidget.ui" line="14"/>
        <source>Form</source>
        <translation>GMIC</translation>
    </message>
    <message>
        <location filename="../ui/languageselectionwidget.ui" line="35"/>
        <source>&lt;i&gt;(Restart needed)&lt;/i&gt;</source>
        <translation>&lt;i&gt;(Changement effectif&lt;br/&gt;au prochain lancement.)&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../ui/languageselectionwidget.ui" line="48"/>
        <source>Translate filters (WIP)</source>
        <translation>Traduire les filtres (WIP)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../ui/mainwindow.ui" line="18"/>
        <source>Form</source>
        <translation>GMIC</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="176"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Download filter definitions from remote sources&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Télécharger les définitions de filtres depuis les sources distantes&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="179"/>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="525"/>
        <location filename="../ui/mainwindow.ui" line="532"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="248"/>
        <location filename="../ui/mainwindow.ui" line="255"/>
        <location filename="../ui/mainwindow.ui" line="262"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="14"/>
        <source>MainWindow</source>
        <translation>MainWindow</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="408"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Enable/disable preview&lt;br/&gt;(Ctrl+P)&lt;br/&gt;(right click on preview image for instant swapping)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Activer/désactiver l&apos;aperçu&lt;br/&gt;(Ctrl+P)&lt;br/&gt;(cliquez droit sur l&apos;image d&apos;aperçu pour basculer instantanément)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="411"/>
        <source>Preview</source>
        <translation>Aperçu</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="418"/>
        <source>Preview type</source>
        <translation>Type de prévisualisation</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="509"/>
        <source>&amp;Settings...</source>
        <translation>&amp;Paramètres...</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="558"/>
        <source>&amp;Close</source>
        <translation>&amp;Fermer</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="571"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="545"/>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Plein écran</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="584"/>
        <source>&amp;Apply</source>
        <translation>&amp;Appliquer</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="597"/>
        <source>&amp;OK</source>
        <translation>&amp;Ok</translation>
    </message>
</context>
<context>
    <name>MultilineTextParameterWidget</name>
    <message>
        <location filename="../ui/multilinetextparameterwidget.ui" line="14"/>
        <source>Form</source>
        <translation>GMIC</translation>
    </message>
    <message>
        <location filename="../ui/multilinetextparameterwidget.ui" line="29"/>
        <source>Update</source>
        <translation>Mettre à jour</translation>
    </message>
</context>
<context>
    <name>ProgressInfoWidget</name>
    <message>
        <location filename="../ui/progressinfowidget.ui" line="14"/>
        <source>Form</source>
        <translation>GMIC</translation>
    </message>
    <message>
        <location filename="../ui/progressinfowidget.ui" line="48"/>
        <source>Abort</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../ui/progressinfowidget.ui" line="55"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
</context>
<context>
    <name>ProgressInfoWindow</name>
    <message>
        <location filename="../ui/progressinfowindow.ui" line="14"/>
        <source>MainWindow</source>
        <translation>MainWindow</translation>
    </message>
    <message>
        <location filename="../ui/progressinfowindow.ui" line="30"/>
        <location filename="../ui/progressinfowindow.ui" line="50"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../ui/progressinfowindow.ui" line="72"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/Host/None/host_none.cpp" line="76"/>
        <source>Select an image to open...</source>
        <translation>Sélectionnez une image à ouvrir...</translation>
    </message>
    <message>
        <location filename="../src/Host/None/host_none.cpp" line="84"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../src/Host/None/host_none.cpp" line="84"/>
        <source>Could not open file.</source>
        <translation>Impossible d&apos;ouvrir le fichier.</translation>
    </message>
    <message>
        <location filename="../src/Host/None/host_none.cpp" line="88"/>
        <source>Default image</source>
        <translation>Image par défaut</translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="81"/>
        <source>Visible</source>
        <translation>Visible</translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="107"/>
        <source>Available filters (%1)</source>
        <translation>Filtres disponibles (%1)</translation>
    </message>
    <message>
        <location filename="../src/Tags.cpp" line="151"/>
        <source>%1 Tag</source>
        <translation>Marqueur %1</translation>
    </message>
    <message>
        <location filename="../src/Tags.cpp" line="157"/>
        <source>None</source>
        <translation>Aucune</translation>
    </message>
    <message>
        <location filename="../src/Tags.cpp" line="158"/>
        <source>Red</source>
        <translation>rouge</translation>
    </message>
    <message>
        <location filename="../src/Tags.cpp" line="159"/>
        <source>Green</source>
        <translation>vert</translation>
    </message>
    <message>
        <location filename="../src/Tags.cpp" line="160"/>
        <source>Blue</source>
        <translation>bleu</translation>
    </message>
    <message>
        <location filename="../src/Tags.cpp" line="161"/>
        <source>Cyan</source>
        <translation>cyan</translation>
    </message>
    <message>
        <location filename="../src/Tags.cpp" line="162"/>
        <source>Magenta</source>
        <translation>magenta</translation>
    </message>
    <message>
        <location filename="../src/Tags.cpp" line="163"/>
        <source>Yellow</source>
        <translation>jaune</translation>
    </message>
    <message>
        <location filename="../src/LanguageSettings.cpp" line="127"/>
        <source>Could not install translator for file %1</source>
        <translation>Impossible d&apos;installer le traducteur pour le fichier %1</translation>
    </message>
    <message>
        <location filename="../src/LanguageSettings.cpp" line="130"/>
        <source>Could not load translation file %1</source>
        <translation>Impossible de charger le fichier de traduction %1</translation>
    </message>
    <message>
        <location filename="../src/Misc.cpp" line="337"/>
        <source>List %1 cannot be merged considering these runs: %2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/Misc.cpp" line="432"/>
        <source>%1 GiB</source>
        <translation>%1 Gio</translation>
    </message>
    <message>
        <location filename="../src/Misc.cpp" line="434"/>
        <source>%1 MiB</source>
        <translation>%1 Mio</translation>
    </message>
    <message>
        <location filename="../src/Misc.cpp" line="436"/>
        <source>%1 KiB</source>
        <translation>%1 Kio</translation>
    </message>
    <message>
        <location filename="../src/Misc.cpp" line="438"/>
        <source>%1 B</source>
        <translation>%1 o</translation>
    </message>
</context>
<context>
    <name>SearchFieldWidget</name>
    <message>
        <location filename="../ui/SearchFieldWidget.ui" line="20"/>
        <source>Frame</source>
        <translation>Frame</translation>
    </message>
</context>
<context>
    <name>SourcesWidget</name>
    <message>
        <location filename="../ui/sourceswidget.ui" line="14"/>
        <source>Form</source>
        <translation>GMIC</translation>
    </message>
    <message>
        <location filename="../ui/sourceswidget.ui" line="136"/>
        <source>Official filters:</source>
        <translation>Filtres officiels :</translation>
    </message>
    <message>
        <location filename="../ui/sourceswidget.ui" line="22"/>
        <source>File / URL</source>
        <translation>Fichier / URL</translation>
    </message>
    <message>
        <location filename="../ui/sourceswidget.ui" line="32"/>
        <source>Add new</source>
        <translation>Ajouter nouveau</translation>
    </message>
    <message>
        <location filename="../ui/sourceswidget.ui" line="39"/>
        <location filename="../ui/sourceswidget.ui" line="55"/>
        <location filename="../ui/sourceswidget.ui" line="62"/>
        <location filename="../ui/sourceswidget.ui" line="85"/>
        <location filename="../ui/sourceswidget.ui" line="92"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../ui/sourceswidget.ui" line="118"/>
        <source>Macros: $HOME $VERSION</source>
        <translation>Macros : $HOME $VERSION</translation>
    </message>
</context>
<context>
    <name>ZoomLevelSelector</name>
    <message>
        <location filename="../ui/zoomlevelselector.ui" line="20"/>
        <source>Form</source>
        <translation>GMIC</translation>
    </message>
</context>
<context>
    <name>gmic_qt_standalone::ImageDialog</name>
    <message>
        <location filename="../src/Host/None/ImageDialog.cpp" line="73"/>
        <source>G&apos;MIC-Qt filter output</source>
        <translation>Résultat du filtre G&apos;MIC-Qt</translation>
    </message>
    <message>
        <location filename="../src/Host/None/ImageDialog.cpp" line="84"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <location filename="../src/Host/None/ImageDialog.cpp" line="87"/>
        <source>Save as...</source>
        <translation>Enregistrer sous...</translation>
    </message>
    <message>
        <location filename="../src/Host/None/ImageDialog.cpp" line="122"/>
        <source>%1 file (*.%2 *.%3)</source>
        <translation>Fichier %1 (*.%2 *.%3)</translation>
    </message>
    <message>
        <location filename="../src/Host/None/ImageDialog.cpp" line="148"/>
        <source>Save image as...</source>
        <translation>Enregistrer l&apos;image sous...</translation>
    </message>
</context>
<context>
    <name>gmic_qt_standalone::ImageView</name>
    <message>
        <location filename="../src/Host/None/ImageDialog.cpp" line="65"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../src/Host/None/ImageDialog.cpp" line="65"/>
        <source>Could not write image file %1</source>
        <translation>Impossible d&apos;écrire le fichier %1</translation>
    </message>
</context>
</TS>
